@@ -1,8 +1,10 @@
 import logging
+import os
+import sys
 from typing import Optional
 
-from waitress import serve
-
+import hupper
+import waitress
 from entropylab.config import settings
 from entropylab.results.dashboard.dashboard import build_dashboard_app
 from entropylab.results.dashboard.theme import theme_stylesheet
@@ -28,13 +30,23 @@ def serve_dashboard(
     if debug is None:
         debug = settings.get("dashboard.debug", False)
 
+    sys.path.append(os.path.abspath(path))
     app = build_dashboard_app(path)
 
+    app.enable_dev_tools(debug=True)
+
     if debug:
-        app.enable_dev_tools(debug=debug)
         entropy_logger = logging.getLogger("entropy")
         entropy_logger.setLevel(logging.DEBUG)
         waitress_logger = logging.getLogger("waitress")
         waitress_logger.setLevel(logging.DEBUG)
 
-    serve(app.server, host=host, port=port)
+    # Hot reloading using hupper
+    worker_kwargs = dict(path=path, host=host, port=port, debug=debug)
+    hupper.start_reloader(
+        "entropylab.results.dashboard.serve_dashboard",
+        worker_kwargs=worker_kwargs,
+        reload_interval=0,
+    )
+
+    waitress.serve(app.server, host=host, port=port)
